==> OpenCL-0.8.3.tgz: OpenCL-0.8.3/src/ecb.cpp <==
/*************************************************
* ECB Mode Source File                           *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/ecb.h>

namespace OpenCL {

/*************************************************
* ECB Encryption Constructor                     *
*************************************************/
ECB::ECB(BlockCipher* c, const BlockCipher_Key& key, const std::string& n) :
   BlockCipherMode(c, n, key, BlockCipherModeIV())
   {
   }

/*************************************************
* Encrypt in ECB mode                            *
*************************************************/
void ECB::write(const byte input[], u32bit length)
   {
   buffer.copy(position, input, length);
   if(position + length >= BLOCK_SIZE)
      {
      do_block(buffer, buffer);
      send(buffer, BLOCK_SIZE);
      input += (BLOCK_SIZE - position);
      length -= (BLOCK_SIZE - position);
      while(length >= BLOCK_SIZE)
         {
         do_block(input, buffer);
         send(buffer, BLOCK_SIZE);
         input += BLOCK_SIZE;
         length -= BLOCK_SIZE;
         }
      buffer.copy(input, length);
      position = 0;
      }
   position += length;
   }

/*************************************************
* Finish encrypting in ECB mode                  *
*************************************************/
void ECB::end_msg()
   {
   if(position)
      throw Exception(name() + ": input was not in full blocks");
   }

}

==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/src/ecb.cpp <==
/*************************************************
* ECB Mode Source File                           *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/ecb.h>

namespace OpenCL {

/*************************************************
* ECB Constructor                                *
*************************************************/
ECB::ECB(BlockCipher* c, const BlockCipher_Key& key, const std::string& n) :
   BlockCipherMode(c, n, key, BlockCipherModeIV())
   {
   }

/*************************************************
* ECB Constructor                                *
*************************************************/
ECB::ECB(const std::string& cipher_name, const BlockCipher_Key& key,
         const std::string& n) :
   BlockCipherMode(cipher_name, n, key, BlockCipherModeIV())
   {
   }

/*************************************************
* Encrypt or Decrypt in ECB mode                 *
*************************************************/
void ECB::write(const byte input[], u32bit length)
   {
   buffer.copy(position, input, length);
   if(position + length >= BLOCK_SIZE)
      {
      process_block(buffer, buffer);
      send(buffer, BLOCK_SIZE);
      input += (BLOCK_SIZE - position);
      length -= (BLOCK_SIZE - position);
      while(length >= BLOCK_SIZE)
         {
         process_block(input, buffer);
         send(buffer, BLOCK_SIZE);
         input += BLOCK_SIZE;
         length -= BLOCK_SIZE;
         }
      buffer.copy(input, length);
      position = 0;
      }
   position += length;
   }

/*************************************************
* Finish encrypting or decrypting in ECB mode    *
*************************************************/
void ECB::end_msg()
   {
   if(position)
      throw Exception(name() + ": input was not in full blocks");
   }

/*************************************************
* ECB Encryption Constructor                     *
*************************************************/
ECB_Encryption::ECB_Encryption(const std::string& cipher_name,
                               const BlockCipher_Key& key) :
   ECB(cipher_name, key, "ECB_Encryption")
   {
   }

/*************************************************
* ECB Encryption Block Processing                *
*************************************************/
void ECB_Encryption::process_block(const byte in[], byte out[])
   {
   cipher->encrypt(in, out);
   }

/*************************************************
* ECB Decryption Constructor                     *
*************************************************/
ECB_Decryption::ECB_Decryption(const std::string& cipher_name,
                               const BlockCipher_Key& key) :
   ECB(cipher_name, key, "ECB_Decryption")
   {
   }

/*************************************************
* ECB Decryption Block Processing                *
*************************************************/
void ECB_Decryption::process_block(const byte in[], byte out[])
   {
   cipher->decrypt(in, out);
   }

}
